.. _all-salt.sdb:

================================
Full list of builtin sdb modules
================================

.. currentmodule:: salt.sdb

.. autosummary::
    :toctree:
    :template: autosummary.rst.tmpl

    couchdb
    etcd_db
    keyring_db
    memcached
    sqlite3
